m8

Struct m8 

pub struct m8(/* private fields */);
Mask type with 8 bits. Its bit pattern is either all ones or all zeros. Unsafe code must not depend on this, however.

Implementations

Source

impl m8

pub const fn new(flag: bool) -> Self

Returns a mask with all bits set one, if flag is true, otherwise returns a mask with all bits set to zero.

pub const fn is_set(self) -> bool

Returns false if the mask bits are all zero, otherwise returns true.